@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10102 2017-07-17 09:34:46Z David $
+# $Id: __init__.py 10109 2017-07-20 07:53:14Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-07-17 17:34:46 +0800 (Mon, 17 Jul 2017) $
-# $Revision: 10102 $
+# $Date: 2017-07-20 15:53:14 +0800 (Thu, 20 Jul 2017) $
+# $Revision: 10109 $
 
 import os
 import sys
@@ -173,13 +173,19 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
     # en/latest/settings.html#settings 
     # http://python-social-auth-docs.readthedocs.io/
     # en/latest/configuration/settings.html#urls-options
-    loginSettingsDefaults = {
-        'LOGIN_URL': '/accounts/login/',
-        'LOGIN_REDIRECT_URL': '/accounts/profile/',
-        'SOCIAL_AUTH_LOGIN_URL': '/accounts/login/',
-        'SOCIAL_AUTH_LOGIN_REDIRECT_URL': '/accounts/profile/',
-        'ACCOUNT_LOGIN_URL': '/accounts/login/',
-        'ACCOUNT_LOGIN_REDIRECT_URL': '/accounts/profile/',
-    }
-
-    update(settingsDict, loginSettingsDefaults)
+    
+    if 'LOGIN_URL' not in settingsDict:
+        settingsDict['LOGIN_URL'] = '/accounts/login/'
+    if 'LOGIN_REDIRECT_URL' not in settingsDict:
+        settingsDict['LOGIN_REDIRECT_URL'] = '/accounts/profile/'
+    
+    if 'SOCIAL_AUTH_LOGIN_URL' not in settingsDict:
+        settingsDict['SOCIAL_AUTH_LOGIN_URL'] = settingsDict['LOGIN_URL']
+    if 'SOCIAL_AUTH_LOGIN_REDIRECT_URL' not in settingsDict:
+        settingsDict['SOCIAL_AUTH_LOGIN_REDIRECT_URL'] = settingsDict[
+                                                         'LOGIN_REDIRECT_URL']
+    if 'ACCOUNT_LOGIN_URL' not in settingsDict:
+        settingsDict['ACCOUNT_LOGIN_URL'] = settingsDict['LOGIN_URL']
+    if 'ACCOUNT_LOGIN_REDIRECT_URL' not in settingsDict:
+        settingsDict['ACCOUNT_LOGIN_REDIRECT_URL'] = settingsDict[
+                                                     'LOGIN_REDIRECT_URL']
