@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: AttachSettingsTest.py 9742 2017-02-08 01:01:19Z David $
+# $Id: AttachSettingsTest.py 10121 2017-07-25 08:18:08Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,13 +12,16 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-02-08 09:01:19 +0800 (Wed, 08 Feb 2017) $
-# $Revision: 9742 $
+# $Date: 2017-07-25 16:18:08 +0800 (Tue, 25 Jul 2017) $
+# $Revision: 10121 $
+
+import os
 
 from django.test import TestCase
 
 from Iuno import member
 
+BASE_DIR = '.'
 class TestAttachSettings(TestCase):
     
     def testSettingsContent(self):
@@ -71,7 +74,8 @@ class TestAttachSettings(TestCase):
                     'ENGINE': 'django.db.backends.sqlite3',
                     'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
                 }
-            },     
+            },
+            'LOGIN_REDIRECT_URL': '/settings',    
         }
         
         member.attachSettings(settingsContent)
@@ -93,16 +97,36 @@ class TestAttachSettings(TestCase):
                             "account.context_processors.account",
                             "django.core.context_processors.request", 
                             "pinax_theme_bootstrap.context_processors.theme",
-                            ("social.apps.django_app.context_processors."
-                             "backends"),
-                            ("social.apps.django_app.context_processors."
-                            "login_redirect"),
+                            "social_django.context_processors.backends",
+                            "social_django.context_processors.login_redirect",  
                         ],
                     },
                 },
             ],
         }
+
+        loginUrlSettings = {
+            'LOGIN_URL': '/accounts/login/',
+            'LOGIN_REDIRECT_URL': '/settings',
+
+            'SOCIAL_AUTH_LOGIN_URL': '/accounts/login/',
+            'SOCIAL_AUTH_LOGIN_REDIRECT_URL': '/settings',
+
+            'ACCOUNT_LOGIN_URL': '/accounts/login/',
+            'ACCOUNT_LOGIN_REDIRECT_URL': '/settings',
+        }
         
         self.assertEqual(settingsContent['TEMPLATES'],
                          templatesSettings['TEMPLATES'])
-        
\ No newline at end of file
+        
+        self.assertEqual(settingsContent['LOGIN_URL'], 
+                         loginUrlSettings['LOGIN_URL'])
+
+        self.assertEqual(settingsContent['LOGIN_REDIRECT_URL'], 
+                         loginUrlSettings['LOGIN_REDIRECT_URL'])
+
+        self.assertEqual(settingsContent['LOGIN_REDIRECT_URL'], 
+                         loginUrlSettings['SOCIAL_AUTH_LOGIN_REDIRECT_URL'])
+        
+        self.assertEqual(settingsContent['ACCOUNT_LOGIN_REDIRECT_URL'], 
+                         loginUrlSettings['SOCIAL_AUTH_LOGIN_REDIRECT_URL'])
\ No newline at end of file
